https://gcc.gnu.org/bugzilla/show_bug.cgi?id=127664

            Bug ID: 127664
           Summary: [17 Regression] 9% slowdown of SPEC 2017 blender_r on
                    znver5 since r17-4551-geb311f861255ae
           Product: gcc
           Version: 17.0
            Status: UNCONFIRMED
          Keywords: missed-optimization
          Severity: normal
          Priority: P3
         Component: tree-optimization
          Assignee: unassigned at gcc dot gnu.org
          Reporter: jmelcr at gcc dot gnu.org
                CC: liuhongt at gcc dot gnu.org
            Blocks: 26163
  Target Milestone: ---
              Host: x86_64-suse-linux
            Target: x86_64-suse-linux
             Build: x86_64-suse-linux

I am seeing a 9% slowdown of SPEC 2017 blender_r on znver5 when compiling with 
-O2 -g -flto=128 with PGO:
https://lnt.opensuse.org/db_default/v4/SPEC/graph?plot.0=1244.487.0

The slowdown bisects to commit r17-4551-geb311f861255ae:
eb311f861255ae1fcaafa3454d4d1d6f1da07497 is the first bad commit
commit eb311f861255ae1fcaafa3454d4d1d6f1da07497
Author: liuhongt <[email protected]>
Date:   Tue Aug 4 01:55:18 2026 -0700

    tree-optimization/126486 - fold sign-changing conversions in IVOPTS

This is a regression against GCC 16:
https://lnt.opensuse.org/db_default/v4/SPEC/graph?plot.0=1306.487.0&plot.1=1363.487.0&plot.2=1557.487.0&plot.3=1244.487.0&;


Referenced Bugs:

https://gcc.gnu.org/bugzilla/show_bug.cgi?id=26163
[Bug 26163] [meta-bug] missed optimization in SPEC (2026, 2k17, 2k and 2k6 and
95)

Reply via email to